@@ -17,16 +17,25 @@ from .sh import PythonSH
 from .pep8_checker import PEP8CheckerMode
 
 
+try:
+    # load pyqode.python resources (code completion icons)
+    from pyqode.python._forms import pyqode_python_icons_rc  # DO NOT REMOVE!!!
+except ImportError:
+    # PyQt/PySide might not be available for the interpreter that run the
+    # backend
+    pass
+
+
 __all__ = [
-    'PyAutoCompleteMode',
-    'PyAutoIndentMode',
+    'Assignment',
     'CalltipsMode',
     'CommentsMode',
     'DocumentAnalyserMode',
     'FrostedCheckerMode',
-    'Assignment',
     'GoToAssignmentsMode',
+    'PEP8CheckerMode',
+    'PyAutoCompleteMode',
+    'PyAutoIndentMode',
     'PyIndenterMode',
     'PythonSH',
-    'PEP8CheckerMode',
 ]
