@@ -3,12 +3,13 @@
 import re
 from pyqode.core.api import TextHelper, get_block_symbol_data
 from pyqode.qt.QtGui import QTextCursor
-from pyqode.core.modes.autoindent import AutoIndentMode
-from pyqode.core.modes.matcher import SymbolMatcherMode
+from pyqode.core.modes import AutoIndentMode, SymbolMatcherMode
+from pyqode.core.modes.matcher import CLOSE, PAREN, SQUARE, BRACE, OPEN
 
 
 class PyAutoIndentMode(AutoIndentMode):
-    """
+    """ Automatically indents text, respecting the PEP8 conventions.
+
     Customised :class:`pyqode.core.modes.AutoIndentMode` for python
     that tries its best to follow the pep8 indentation guidelines.
 
@@ -120,6 +121,10 @@ class PyAutoIndentMode(AutoIndentMode):
         return len(open_p), len(closed_p), open_p, closed_p
 
     def _between_paren(self, tc, col):
+        try:
+            self.editor.modes.get('SymbolMatcherMode')
+        except KeyError:
+            return False
         block = tc.block()
         nb_open = nb_closed = 0
         while block.isValid() and block.text().strip():
@@ -133,14 +138,14 @@ class PyAutoIndentMode(AutoIndentMode):
     @staticmethod
     def _get_last_word(tc):
         tc2 = QTextCursor(tc)
-        tc2.movePosition(QTextCursor.Left, 1)
+        tc2.movePosition(QTextCursor.Left, tc.KeepAnchor, 1)
         tc2.movePosition(QTextCursor.WordLeft, tc.KeepAnchor)
         return tc2.selectedText().strip()
 
     @staticmethod
     def _get_last_word_unstripped(tc):
         tc2 = QTextCursor(tc)
-        tc2.movePosition(QTextCursor.Left, 1)
+        tc2.movePosition(QTextCursor.Left, tc.KeepAnchor, 1)
         tc2.movePosition(QTextCursor.WordLeft, tc.KeepAnchor)
         return tc2.selectedText()
 
@@ -148,7 +153,11 @@ class PyAutoIndentMode(AutoIndentMode):
         tc.movePosition(tc.Left, tc.KeepAnchor)
         char = tc.selectedText()
         tc.movePosition(tc.Right, tc.MoveAnchor)
-        mapping = {')': ('(', 0), '}': ('{', 1), ']': ('[', 2)}
+        mapping = {
+            ')': (OPEN, PAREN),
+            ']': (OPEN, SQUARE),
+            '}': (OPEN, BRACE)
+        }
         try:
             character, char_type = mapping[char]
         except KeyError:
@@ -164,7 +173,11 @@ class PyAutoIndentMode(AutoIndentMode):
         char = None
         ln = tc.blockNumber()
         tc_trav = QTextCursor(tc)
-        mapping = {'(': (')', 0), '[': (']', 1), '{': ('}', 2)}
+        mapping = {
+            '(': (CLOSE, PAREN),
+            '[': (CLOSE, SQUARE),
+            '{': (CLOSE, BRACE)
+        }
         while ln >= 0 and tc.block().text().strip():
             tc_trav.movePosition(tc_trav.StartOfLine, tc_trav.MoveAnchor)
             lists = get_block_symbol_data(self.editor, tc_trav.block())
@@ -202,21 +215,14 @@ class PyAutoIndentMode(AutoIndentMode):
 
     def _get_paren_pos(self, tc, column):
         pos, char = self._get_first_open_paren(tc, column)
-        if char == '(':
-            ptype = 0
-            closingchar = ')'
-        elif char == '[':
-            ptype = 1
-            closingchar = ']'
-        else:
-            ptype = 2
-            closingchar = '}'
+        mapping = {'(': PAREN, '[': SQUARE, '{': BRACE}
         tc2 = QTextCursor(tc)
         tc2.setPosition(pos)
+        import sys
         ol, oc = self.editor.modes.get(SymbolMatcherMode).symbol_pos(
-            tc2, char, ptype)
+            tc2, OPEN, mapping[char])
         cl, cc = self.editor.modes.get(SymbolMatcherMode).symbol_pos(
-            tc2, closingchar, ptype)
+            tc2, CLOSE, mapping[char])
         return (ol, oc), (cl, cc)
 
     @staticmethod
@@ -269,7 +275,10 @@ class PyAutoIndentMode(AutoIndentMode):
         # breaking string
         if next_char in ['"', "'"]:
             tc.movePosition(tc.Left)
-        if self._helper.is_comment_or_string(tc, formats=['string']):
+        is_string = self._helper.is_comment_or_string(tc, formats=['string'])
+        if next_char in ['"', "'"]:
+            tc.movePosition(tc.Right)
+        if is_string:
             trav = QTextCursor(tc)
             while self._helper.is_comment_or_string(
                     trav, formats=['string']):
