@@ -2,6 +2,9 @@
 """
 This package contains the python code editor widget
 """
+import sys
+from pyqode.core.api import ColorScheme
+from pyqode.python.backend import server
 from pyqode.qt import QtCore, QtGui
 from pyqode.core import api
 from pyqode.core import modes
@@ -10,32 +13,51 @@ from pyqode.python import managers as pymanagers
 from pyqode.python import modes as pymodes
 from pyqode.python import panels as pypanels
 from pyqode.python.folding import PythonFoldDetector
-# load pyqode.python resources (code completion icons)
-# DO NOT REMOVE
-from pyqode.python._forms import pyqode_python_icons_rc
 
 
-class PyCodeEdit(api.CodeEdit):
+class PyCodeEditBase(api.CodeEdit):
     """
-    Extends CodeEdit with a hardcoded set of modes and panels specifics to
-    a python code editor widget.
-
-    It also implements utility methods to switch from a white style to a dark
-    style and inversely.
+    Base class for creating a python code editor widget. The base class
+    takes care of setting up the syntax highlighter.
 
     .. note:: This code editor widget use PEP 0263 to detect file encoding.
               If the opened file does not respects the PEP 0263,
               :py:func:`locale.getpreferredencoding` is used as the default
               encoding.
     """
+
+    def __init__(self, parent=None, create_default_actions=True,
+                 color_scheme='qt'):
+        super(PyCodeEditBase, self).__init__(parent, create_default_actions)
+        self.file = pymanagers.PyFileManager(self)
+
+    def setPlainText(self, txt, mimetype='text/x-python', encoding='utf-8'):
+        """
+        Extends QCodeEdit.setPlainText to allow user to setPlainText without
+        mimetype (since the python syntax highlighter does not use it).
+        """
+        self.syntax_highlighter.docstrings[:] = []
+        self.syntax_highlighter.import_statements[:] = []
+        super(PyCodeEditBase, self).setPlainText(txt, mimetype, encoding)
+
+
+class PyCodeEdit(PyCodeEditBase):
+    """
+    Extends PyCodeEditBase with a set of hardcoded modes and panels specifics
+    to a python code editor widget.
+    """
     DARK_STYLE = 0
     LIGHT_STYLE = 1
 
     mimetypes = ['text/x-python']
 
-    def __init__(self, parent=None):
-        super(PyCodeEdit, self).__init__(parent)
-        self.file = pymanagers.PyFileManager(self)
+    def __init__(self, parent=None, server_script=server.__file__,
+                 interpreter=sys.executable, args=None,
+                 create_default_actions=True, color_scheme='qt'):
+        super(PyCodeEdit, self).__init__(
+            parent=parent, create_default_actions=create_default_actions,
+            color_scheme=color_scheme)
+        self.backend.start(server_script, interpreter, args)
         self.setLineWrapMode(self.NoWrap)
         self.setWindowTitle("pyQode - Python Editor")
 
@@ -50,8 +72,6 @@ class PyCodeEdit(api.CodeEdit):
                            panels.GlobalCheckerPanel.Position.RIGHT)
         self.panels.append(panels.SearchAndReplacePanel(),
                            panels.SearchAndReplacePanel.Position.BOTTOM)
-        self.panels.append(pypanels.SymbolBrowserPanel(),
-                           pypanels.SymbolBrowserPanel.Position.TOP)
         self.panels.append(panels.EncodingPanel(), api.Panel.Position.TOP)
         self.add_separator()
         self.panels.append(pypanels.QuickDocPanel(), api.Panel.Position.BOTTOM)
@@ -68,7 +88,6 @@ class PyCodeEdit(api.CodeEdit):
         self.modes.append(modes.SmartBackSpaceMode())
         self.modes.append(modes.ExtendedSelectionMode())
         # python specifics
-        self.modes.append(pymodes.PythonSH(self.document()))
         self.modes.append(pymodes.PyAutoIndentMode())
         self.modes.append(pymodes.PyAutoCompleteMode())
         self.modes.append(pymodes.FrostedCheckerMode())
@@ -77,14 +96,16 @@ class PyCodeEdit(api.CodeEdit):
         self.modes.append(pymodes.PyIndenterMode())
         self.modes.append(pymodes.GoToAssignmentsMode())
         self.modes.append(pymodes.CommentsMode())
-
+        self.modes.append(pymodes.PythonSH(
+            self.document(), color_scheme=ColorScheme(color_scheme)))
         self.syntax_highlighter.fold_detector = PythonFoldDetector()
 
-    def setPlainText(self, txt, mimetype='text/x-python', encoding='utf-8'):
-        """
-        Extends QCodeEdit.setPlainText to allow user to setPlainText without
-        mimetype (since the python syntax highlighter does not use it).
-        """
-        self.syntax_highlighter.docstrings[:] = []
-        self.syntax_highlighter.import_statements[:] = []
-        super(PyCodeEdit, self).setPlainText(txt, mimetype, encoding)
+    def clone(self):
+        clone = self.__class__(
+            parent=self.parent(), server_script=self.backend.server_script,
+            interpreter=self.backend.interpreter, args=self.backend.args,
+            color_scheme=self.syntax_highlighter.color_scheme.name)
+        return clone
+
+    def __repr__(self):
+        return 'PyCodeEdit(path=%r)' % self.file.path
