@@ -30,9 +30,8 @@ class PyInteractiveConsole(InteractiveConsole):
         self.set_writer(self._write)
         self.setMouseTracking(True)
         self.PROG = QtCore.QRegExp(
-            r'\s*File "[a-zA-Z\/_\d]*((.\.[a-zA-Z\/_\d]*")|(")), '
-            r'line [0-9]*.*')
-        self.FILENAME_PROG = QtCore.QRegExp(r'"[a-zA-Z\/_\.\d]*"')
+            r'\s*File "[a-zA-Z\/_\d:\\]*((.\.[a-zA-Z\/_\d:\\]*")|(")), line [0-9]*.*')
+        self.FILENAME_PROG = QtCore.QRegExp(r'"[a-zA-Z\/_\.\d:\\]*"')
         self.LINE_PROG = QtCore.QRegExp(r'line [0-9]*')
         self.setLineWrapMode(self.NoWrap)
         self._module_color = QtGui.QColor('blue')
@@ -62,6 +61,7 @@ class PyInteractiveConsole(InteractiveConsole):
             block.setUserData(data)
 
         text = text.replace('\n', '{@}\n')
+        text = text.replace('\r', '')
         for i, line in enumerate(text.split('{@}')):
             # check if File and highlight it in blue, also store it
             if self.PROG.indexIn(line) != -1:
